@@ -1,5 +1,6 @@
 from .core.trainer import Trainer, TrainerArgs
 from .core.hyperparams import Hyperparams, HyperparamsSpec
-from .core.evaluator import evaluate, predict_single
+from .core.evaluator import evaluate
 from .core.auto_tuner import AutoTuner
 from .helper_funcs import train, autotune
+from .mixins import ModuleMixin
