@@ -33,9 +33,3 @@ def evaluate(model: t.nn.Module, dataloader: DataLoader, metrics: Sequence[Metri
         mval = np.around(metric(outputs, targets), 3)
         mvals.append(mval)
     return mvals
-
-
-def predict_single(model: t.nn.Module, x: t.Tensor):
-    batch_of_one = x.usqueeze(0)
-    y_hat = model(batch_of_one).squeeze()
-    return y_hat
